@@ -24,7 +24,7 @@
 from __future__ import annotations
 from typing import List
 from .GeneratorUtils import GeneratorUtils
-from .AccountKeyFlagsDto import AccountKeyFlagsDto
+from .AccountKeyTypeFlagsDto import AccountKeyTypeFlagsDto
 from .AccountStateFormatDto import AccountStateFormatDto
 from .AccountTypeDto import AccountTypeDto
 from .AddressDto import AddressDto
@@ -33,8 +33,7 @@ from .HeightDto import HeightDto
 from .ImportanceSnapshotBuilder import ImportanceSnapshotBuilder
 from .KeyDto import KeyDto
 from .MosaicBuilder import MosaicBuilder
-from .MosaicIdDto import MosaicIdDto
-from .VotingKeyDto import VotingKeyDto
+from .PinnedVotingKeyBuilder import PinnedVotingKeyBuilder
 
 
 class AccountStateBuilder:
@@ -47,18 +46,17 @@ class AccountStateBuilder:
         publicKeyHeight: Height at which public key has been obtained.
         accountType: Type of account.
         format: Account format.
-        supplementalAccountKeysMask: Mask of supplemental account key flags.
+        supplementalPublicKeysMask: Mask of supplemental public key flags.
         linkedPublicKey: Linked account public key.
-        vrfPublicKey: Vrf public key.
-        votingPublicKey: Voting public key.
         nodePublicKey: Node public key.
+        vrfPublicKey: Vrf public key.
+        votingPublicKeys: Voting public keys.
         importanceSnapshots: Current importance snapshot of the account.
         activityBuckets: Activity buckets of the account.
-        currencyMosaicId: Currency mosaic id.
         balances: Balances of account.
     """
 
-    def __init__(self, address: AddressDto, addressHeight: HeightDto, publicKey: KeyDto, publicKeyHeight: HeightDto, accountType: AccountTypeDto, format: AccountStateFormatDto, supplementalAccountKeysMask: List[AccountKeyFlagsDto], linkedPublicKey: KeyDto, vrfPublicKey: KeyDto, votingPublicKey: VotingKeyDto, nodePublicKey: KeyDto, importanceSnapshots: ImportanceSnapshotBuilder, activityBuckets: HeightActivityBucketsBuilder, currencyMosaicId: MosaicIdDto, balances: List[MosaicBuilder]):
+    def __init__(self, address: AddressDto, addressHeight: HeightDto, publicKey: KeyDto, publicKeyHeight: HeightDto, accountType: AccountTypeDto, format: AccountStateFormatDto, supplementalPublicKeysMask: List[AccountKeyTypeFlagsDto], linkedPublicKey: KeyDto, nodePublicKey: KeyDto, vrfPublicKey: KeyDto, votingPublicKeys: List[PinnedVotingKeyBuilder], importanceSnapshots: ImportanceSnapshotBuilder, activityBuckets: HeightActivityBucketsBuilder, balances: List[MosaicBuilder]):
         """Constructor.
         Args:
             address: Address of account.
@@ -67,14 +65,13 @@ class AccountStateBuilder:
             publicKeyHeight: Height at which public key has been obtained.
             accountType: Type of account.
             format: Account format.
-            supplementalAccountKeysMask: Mask of supplemental account key flags.
+            supplementalPublicKeysMask: Mask of supplemental public key flags.
             linkedPublicKey: Linked account public key.
-            vrfPublicKey: Vrf public key.
-            votingPublicKey: Voting public key.
             nodePublicKey: Node public key.
+            vrfPublicKey: Vrf public key.
+            votingPublicKeys: Voting public keys.
             importanceSnapshots: Current importance snapshot of the account.
             activityBuckets: Activity buckets of the account.
-            currencyMosaicId: Currency mosaic id.
             balances: Balances of account.
         """
         self.address = address
@@ -83,14 +80,13 @@ class AccountStateBuilder:
         self.publicKeyHeight = publicKeyHeight
         self.accountType = accountType
         self.format = format
-        self.supplementalAccountKeysMask = supplementalAccountKeysMask
+        self.supplementalPublicKeysMask = supplementalPublicKeysMask
         self.linkedPublicKey = linkedPublicKey
-        self.vrfPublicKey = vrfPublicKey
-        self.votingPublicKey = votingPublicKey
         self.nodePublicKey = nodePublicKey
+        self.vrfPublicKey = vrfPublicKey
+        self.votingPublicKeys = votingPublicKeys
         self.importanceSnapshots = importanceSnapshots
         self.activityBuckets = activityBuckets
-        self.currencyMosaicId = currencyMosaicId
         self.balances = balances
 
     @classmethod
@@ -114,10 +110,15 @@ class AccountStateBuilder:
         bytes_ = bytes_[accountType.getSize():]
         format = AccountStateFormatDto.loadFromBinary(bytes_)  # kind:CUSTOM2
         bytes_ = bytes_[format.getSize():]
-        supplementalAccountKeysMask = AccountKeyFlagsDto.bytesToFlags(bytes_, 1)  # kind:FLAGS
+        supplementalPublicKeysMask = AccountKeyTypeFlagsDto.bytesToFlags(bytes_, 1)  # kind:FLAGS
         bytes_ = bytes_[1:]
-        currencyMosaicId = MosaicIdDto.loadFromBinary(bytes_)  # kind:CUSTOM1
-        bytes_ = bytes_[currencyMosaicId.getSize():]
+        votingPublicKeysCount = GeneratorUtils.bufferToUint(GeneratorUtils.getBytes(bytes_, 1))  # kind:SIZE_FIELD
+        bytes_ = bytes_[1:]
+        votingPublicKeys: List[PinnedVotingKeyBuilder] = []  # kind:ARRAY
+        for _ in range(votingPublicKeysCount):
+            item = PinnedVotingKeyBuilder.loadFromBinary(bytes_)
+            votingPublicKeys.append(item)
+            bytes_ = bytes_[item.getSize():]
         balancesCount = GeneratorUtils.bufferToUint(GeneratorUtils.getBytes(bytes_, 2))  # kind:SIZE_FIELD
         bytes_ = bytes_[2:]
         balances: List[MosaicBuilder] = []  # kind:ARRAY
@@ -126,24 +127,21 @@ class AccountStateBuilder:
             balances.append(item)
             bytes_ = bytes_[item.getSize():]
         linkedPublicKey = None
-        if AccountKeyFlagsDto.LINKED in supplementalAccountKeysMask:
+        if AccountKeyTypeFlagsDto.LINKED in supplementalPublicKeysMask:
             linkedPublicKey = KeyDto.loadFromBinary(bytes_)  # kind:CUSTOM3
-        vrfPublicKey = None
-        if AccountKeyFlagsDto.VRF in supplementalAccountKeysMask:
-            vrfPublicKey = KeyDto.loadFromBinary(bytes_)  # kind:CUSTOM3
-        votingPublicKey = None
-        if AccountKeyFlagsDto.VOTING in supplementalAccountKeysMask:
-            votingPublicKey = VotingKeyDto.loadFromBinary(bytes_)  # kind:CUSTOM3
         nodePublicKey = None
-        if AccountKeyFlagsDto.NODE in supplementalAccountKeysMask:
+        if AccountKeyTypeFlagsDto.NODE in supplementalPublicKeysMask:
             nodePublicKey = KeyDto.loadFromBinary(bytes_)  # kind:CUSTOM3
+        vrfPublicKey = None
+        if AccountKeyTypeFlagsDto.VRF in supplementalPublicKeysMask:
+            vrfPublicKey = KeyDto.loadFromBinary(bytes_)  # kind:CUSTOM3
         importanceSnapshots = None
         if format == AccountStateFormatDto.HIGH_VALUE:
             importanceSnapshots = ImportanceSnapshotBuilder.loadFromBinary(bytes_)  # kind:CUSTOM3
         activityBuckets = None
         if format == AccountStateFormatDto.HIGH_VALUE:
             activityBuckets = HeightActivityBucketsBuilder.loadFromBinary(bytes_)  # kind:CUSTOM3
-        return AccountStateBuilder(address, addressHeight, publicKey, publicKeyHeight, accountType, format, supplementalAccountKeysMask, linkedPublicKey, vrfPublicKey, votingPublicKey, nodePublicKey, importanceSnapshots, activityBuckets, currencyMosaicId, balances)
+        return AccountStateBuilder(address, addressHeight, publicKey, publicKeyHeight, accountType, format, supplementalPublicKeysMask, linkedPublicKey, nodePublicKey, vrfPublicKey, votingPublicKeys, importanceSnapshots, activityBuckets, balances)
 
     def getAddress(self) -> AddressDto:
         """Gets address of account.
@@ -187,49 +185,47 @@ class AccountStateBuilder:
         """
         return self.format
 
-    def getSupplementalAccountKeysMask(self) -> List[AccountKeyFlagsDto]:
-        """Gets mask of supplemental account key flags.
+    def getSupplementalPublicKeysMask(self) -> List[AccountKeyTypeFlagsDto]:
+        """Gets mask of supplemental public key flags.
         Returns:
-            Mask of supplemental account key flags.
+            Mask of supplemental public key flags.
         """
-        return self.supplementalAccountKeysMask
+        return self.supplementalPublicKeysMask
 
     def getLinkedPublicKey(self) -> KeyDto:
         """Gets linked account public key.
         Returns:
             Linked account public key.
         """
-        if not AccountKeyFlagsDto.LINKED in self.supplementalAccountKeysMask:
-            raise Exception('supplementalAccountKeysMask is not set to LINKED.')
+        if not AccountKeyTypeFlagsDto.LINKED in self.supplementalPublicKeysMask:
+            raise Exception('supplementalPublicKeysMask is not set to LINKED.')
         return self.linkedPublicKey
 
-    def getVrfPublicKey(self) -> KeyDto:
-        """Gets vrf public key.
-        Returns:
-            Vrf public key.
-        """
-        if not AccountKeyFlagsDto.VRF in self.supplementalAccountKeysMask:
-            raise Exception('supplementalAccountKeysMask is not set to VRF.')
-        return self.vrfPublicKey
-
-    def getVotingPublicKey(self) -> VotingKeyDto:
-        """Gets voting public key.
-        Returns:
-            Voting public key.
-        """
-        if not AccountKeyFlagsDto.VOTING in self.supplementalAccountKeysMask:
-            raise Exception('supplementalAccountKeysMask is not set to VOTING.')
-        return self.votingPublicKey
-
     def getNodePublicKey(self) -> KeyDto:
         """Gets node public key.
         Returns:
             Node public key.
         """
-        if not AccountKeyFlagsDto.NODE in self.supplementalAccountKeysMask:
-            raise Exception('supplementalAccountKeysMask is not set to NODE.')
+        if not AccountKeyTypeFlagsDto.NODE in self.supplementalPublicKeysMask:
+            raise Exception('supplementalPublicKeysMask is not set to NODE.')
         return self.nodePublicKey
 
+    def getVrfPublicKey(self) -> KeyDto:
+        """Gets vrf public key.
+        Returns:
+            Vrf public key.
+        """
+        if not AccountKeyTypeFlagsDto.VRF in self.supplementalPublicKeysMask:
+            raise Exception('supplementalPublicKeysMask is not set to VRF.')
+        return self.vrfPublicKey
+
+    def getVotingPublicKeys(self) -> List[PinnedVotingKeyBuilder]:
+        """Gets voting public keys.
+        Returns:
+            Voting public keys.
+        """
+        return self.votingPublicKeys
+
     def getImportanceSnapshots(self) -> ImportanceSnapshotBuilder:
         """Gets current importance snapshot of the account.
         Returns:
@@ -248,13 +244,6 @@ class AccountStateBuilder:
             raise Exception('format is not set to HIGH_VALUE.')
         return self.activityBuckets
 
-    def getCurrencyMosaicId(self) -> MosaicIdDto:
-        """Gets currency mosaic id.
-        Returns:
-            Currency mosaic id.
-        """
-        return self.currencyMosaicId
-
     def getBalances(self) -> List[MosaicBuilder]:
         """Gets balances of account.
         Returns:
@@ -274,20 +263,20 @@ class AccountStateBuilder:
         size += self.publicKeyHeight.getSize()
         size += self.accountType.getSize()
         size += self.format.getSize()
-        size += 1  # supplementalAccountKeysMask
-        if AccountKeyFlagsDto.LINKED in self.supplementalAccountKeysMask:
+        size += 1  # supplementalPublicKeysMask
+        size += 1  # votingPublicKeysCount
+        if AccountKeyTypeFlagsDto.LINKED in self.supplementalPublicKeysMask:
             size += self.linkedPublicKey.getSize()
-        if AccountKeyFlagsDto.VRF in self.supplementalAccountKeysMask:
-            size += self.vrfPublicKey.getSize()
-        if AccountKeyFlagsDto.VOTING in self.supplementalAccountKeysMask:
-            size += self.votingPublicKey.getSize()
-        if AccountKeyFlagsDto.NODE in self.supplementalAccountKeysMask:
+        if AccountKeyTypeFlagsDto.NODE in self.supplementalPublicKeysMask:
             size += self.nodePublicKey.getSize()
+        if AccountKeyTypeFlagsDto.VRF in self.supplementalPublicKeysMask:
+            size += self.vrfPublicKey.getSize()
+        for _ in self.votingPublicKeys:
+            size += _.getSize()
         if self.format == AccountStateFormatDto.HIGH_VALUE:
             size += self.importanceSnapshots.getSize()
         if self.format == AccountStateFormatDto.HIGH_VALUE:
             size += self.activityBuckets.getSize()
-        size += self.currencyMosaicId.getSize()
         size += 2  # balancesCount
         for _ in self.balances:
             size += _.getSize()
@@ -305,20 +294,20 @@ class AccountStateBuilder:
         bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.publicKeyHeight.serialize())  # kind:CUSTOM
         bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.accountType.serialize())  # kind:CUSTOM
         bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.format.serialize())  # kind:CUSTOM
-        bytes_ = GeneratorUtils.concatTypedArrays(bytes_, AccountKeyFlagsDto.flagsToInt(self.getSupplementalAccountKeysMask()))  # kind:FLAGS
-        if AccountKeyFlagsDto.LINKED in self.supplementalAccountKeysMask:
+        bytes_ = GeneratorUtils.concatTypedArrays(bytes_, AccountKeyTypeFlagsDto.flagsToInt(self.getSupplementalPublicKeysMask()))  # kind:FLAGS
+        bytes_ = GeneratorUtils.concatTypedArrays(bytes_, GeneratorUtils.uintToBuffer(len(self.getVotingPublicKeys()), 1))  # kind:SIZE_FIELD
+        if AccountKeyTypeFlagsDto.LINKED in self.supplementalPublicKeysMask:
             bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.linkedPublicKey.serialize())  # kind:CUSTOM
-        if AccountKeyFlagsDto.VRF in self.supplementalAccountKeysMask:
-            bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.vrfPublicKey.serialize())  # kind:CUSTOM
-        if AccountKeyFlagsDto.VOTING in self.supplementalAccountKeysMask:
-            bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.votingPublicKey.serialize())  # kind:CUSTOM
-        if AccountKeyFlagsDto.NODE in self.supplementalAccountKeysMask:
+        if AccountKeyTypeFlagsDto.NODE in self.supplementalPublicKeysMask:
             bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.nodePublicKey.serialize())  # kind:CUSTOM
+        if AccountKeyTypeFlagsDto.VRF in self.supplementalPublicKeysMask:
+            bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.vrfPublicKey.serialize())  # kind:CUSTOM
+        for _ in self.votingPublicKeys:
+            bytes_ = GeneratorUtils.concatTypedArrays(bytes_, _.serialize())  # kind:ARRAY|VAR_ARRAY|FILL_ARRAY
         if self.format == AccountStateFormatDto.HIGH_VALUE:
             bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.importanceSnapshots.serialize())  # kind:CUSTOM
         if self.format == AccountStateFormatDto.HIGH_VALUE:
             bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.activityBuckets.serialize())  # kind:CUSTOM
-        bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.currencyMosaicId.serialize())  # kind:CUSTOM
         bytes_ = GeneratorUtils.concatTypedArrays(bytes_, GeneratorUtils.uintToBuffer(len(self.getBalances()), 2))  # kind:SIZE_FIELD
         for _ in self.balances:
             bytes_ = GeneratorUtils.concatTypedArrays(bytes_, _.serialize())  # kind:ARRAY|VAR_ARRAY|FILL_ARRAY
