@@ -28,6 +28,7 @@ from .EmbeddedTransactionBuilder import EmbeddedTransactionBuilder
 from .EntityTypeDto import EntityTypeDto
 from .KeyDto import KeyDto
 from .NetworkTypeDto import NetworkTypeDto
+from .UnresolvedAddressDto import UnresolvedAddressDto
 
 
 class EmbeddedAccountMetadataTransactionBuilder(EmbeddedTransactionBuilder):
@@ -37,7 +38,7 @@ class EmbeddedAccountMetadataTransactionBuilder(EmbeddedTransactionBuilder):
         accountMetadataTransactionBody: Account metadata transaction body.
     """
 
-    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, targetPublicKey: KeyDto, scopedMetadataKey: int, valueSizeDelta: int, value: bytes):
+    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, targetAddress: UnresolvedAddressDto, scopedMetadataKey: int, valueSizeDelta: int, value: bytes):
         """Constructor.
         Args:
             size: Entity size.
@@ -45,13 +46,13 @@ class EmbeddedAccountMetadataTransactionBuilder(EmbeddedTransactionBuilder):
             version: Entity version.
             network: Entity network.
             type: Entity type.
-            targetPublicKey: Metadata target public key.
+            targetAddress: Metadata target address.
             scopedMetadataKey: Metadata key scoped to source, target and type.
             valueSizeDelta: Change in value size in bytes.
             value: Difference between existing value and new value \note when there is no existing value, new value is same this value \note when there is an existing value, new value is calculated as xor(previous-value, value).
         """
         super().__init__(size, signerPublicKey, version, network, type)
-        self.accountMetadataTransactionBody = AccountMetadataTransactionBodyBuilder(targetPublicKey, scopedMetadataKey, valueSizeDelta, value)
+        self.accountMetadataTransactionBody = AccountMetadataTransactionBodyBuilder(targetAddress, scopedMetadataKey, valueSizeDelta, value)
 
     @classmethod
     def loadFromBinary(cls, payload: bytes) -> EmbeddedAccountMetadataTransactionBuilder:
@@ -66,14 +67,14 @@ class EmbeddedAccountMetadataTransactionBuilder(EmbeddedTransactionBuilder):
         bytes_ = bytes_[superObject.getSize():]
         accountMetadataTransactionBody = AccountMetadataTransactionBodyBuilder.loadFromBinary(bytes_)  # kind:CUSTOM1
         bytes_ = bytes_[accountMetadataTransactionBody.getSize():]
-        return EmbeddedAccountMetadataTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, accountMetadataTransactionBody.targetPublicKey, accountMetadataTransactionBody.scopedMetadataKey, accountMetadataTransactionBody.valueSizeDelta, accountMetadataTransactionBody.value)
+        return EmbeddedAccountMetadataTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, accountMetadataTransactionBody.targetAddress, accountMetadataTransactionBody.scopedMetadataKey, accountMetadataTransactionBody.valueSizeDelta, accountMetadataTransactionBody.value)
 
-    def getTargetPublicKey(self) -> KeyDto:
-        """Gets metadata target public key.
+    def getTargetAddress(self) -> UnresolvedAddressDto:
+        """Gets metadata target address.
         Returns:
-            Metadata target public key.
+            Metadata target address.
         """
-        return self.accountMetadataTransactionBody.getTargetPublicKey()
+        return self.accountMetadataTransactionBody.getTargetAddress()
 
     def getScopedMetadataKey(self) -> int:
         """Gets metadata key scoped to source, target and type.
