@@ -42,7 +42,7 @@ class EmbeddedSecretLockTransactionBuilder(EmbeddedTransactionBuilder):
         secretLockTransactionBody: Secret lock transaction body.
     """
 
-    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, secret: Hash256Dto, mosaic: UnresolvedMosaicBuilder, duration: BlockDurationDto, hashAlgorithm: LockHashAlgorithmDto, recipientAddress: UnresolvedAddressDto):
+    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, recipientAddress: UnresolvedAddressDto, secret: Hash256Dto, mosaic: UnresolvedMosaicBuilder, duration: BlockDurationDto, hashAlgorithm: LockHashAlgorithmDto):
         """Constructor.
         Args:
             size: Entity size.
@@ -50,14 +50,14 @@ class EmbeddedSecretLockTransactionBuilder(EmbeddedTransactionBuilder):
             version: Entity version.
             network: Entity network.
             type: Entity type.
+            recipientAddress: Locked mosaic recipient address.
             secret: Secret.
             mosaic: Locked mosaic.
             duration: Number of blocks for which a lock should be valid.
             hashAlgorithm: Hash algorithm.
-            recipientAddress: Locked mosaic recipient address.
         """
         super().__init__(size, signerPublicKey, version, network, type)
-        self.secretLockTransactionBody = SecretLockTransactionBodyBuilder(secret, mosaic, duration, hashAlgorithm, recipientAddress)
+        self.secretLockTransactionBody = SecretLockTransactionBodyBuilder(recipientAddress, secret, mosaic, duration, hashAlgorithm)
 
     @classmethod
     def loadFromBinary(cls, payload: bytes) -> EmbeddedSecretLockTransactionBuilder:
@@ -72,7 +72,14 @@ class EmbeddedSecretLockTransactionBuilder(EmbeddedTransactionBuilder):
         bytes_ = bytes_[superObject.getSize():]
         secretLockTransactionBody = SecretLockTransactionBodyBuilder.loadFromBinary(bytes_)  # kind:CUSTOM1
         bytes_ = bytes_[secretLockTransactionBody.getSize():]
-        return EmbeddedSecretLockTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, secretLockTransactionBody.secret, secretLockTransactionBody.mosaic, secretLockTransactionBody.duration, secretLockTransactionBody.hashAlgorithm, secretLockTransactionBody.recipientAddress)
+        return EmbeddedSecretLockTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, secretLockTransactionBody.recipientAddress, secretLockTransactionBody.secret, secretLockTransactionBody.mosaic, secretLockTransactionBody.duration, secretLockTransactionBody.hashAlgorithm)
+
+    def getRecipientAddress(self) -> UnresolvedAddressDto:
+        """Gets locked mosaic recipient address.
+        Returns:
+            Locked mosaic recipient address.
+        """
+        return self.secretLockTransactionBody.getRecipientAddress()
 
     def getSecret(self) -> Hash256Dto:
         """Gets secret.
@@ -102,13 +109,6 @@ class EmbeddedSecretLockTransactionBuilder(EmbeddedTransactionBuilder):
         """
         return self.secretLockTransactionBody.getHashAlgorithm()
 
-    def getRecipientAddress(self) -> UnresolvedAddressDto:
-        """Gets locked mosaic recipient address.
-        Returns:
-            Locked mosaic recipient address.
-        """
-        return self.secretLockTransactionBody.getRecipientAddress()
-
     def getSize(self) -> int:
         """Gets the size of the object.
         Returns:
