@@ -40,7 +40,7 @@ class EmbeddedSecretProofTransactionBuilder(EmbeddedTransactionBuilder):
         secretProofTransactionBody: Secret proof transaction body.
     """
 
-    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, secret: Hash256Dto, hashAlgorithm: LockHashAlgorithmDto, recipientAddress: UnresolvedAddressDto, proof: bytes):
+    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, recipientAddress: UnresolvedAddressDto, secret: Hash256Dto, hashAlgorithm: LockHashAlgorithmDto, proof: bytes):
         """Constructor.
         Args:
             size: Entity size.
@@ -48,13 +48,13 @@ class EmbeddedSecretProofTransactionBuilder(EmbeddedTransactionBuilder):
             version: Entity version.
             network: Entity network.
             type: Entity type.
+            recipientAddress: Locked mosaic recipient address.
             secret: Secret.
             hashAlgorithm: Hash algorithm.
-            recipientAddress: Locked mosaic recipient address.
             proof: Proof data.
         """
         super().__init__(size, signerPublicKey, version, network, type)
-        self.secretProofTransactionBody = SecretProofTransactionBodyBuilder(secret, hashAlgorithm, recipientAddress, proof)
+        self.secretProofTransactionBody = SecretProofTransactionBodyBuilder(recipientAddress, secret, hashAlgorithm, proof)
 
     @classmethod
     def loadFromBinary(cls, payload: bytes) -> EmbeddedSecretProofTransactionBuilder:
@@ -69,7 +69,14 @@ class EmbeddedSecretProofTransactionBuilder(EmbeddedTransactionBuilder):
         bytes_ = bytes_[superObject.getSize():]
         secretProofTransactionBody = SecretProofTransactionBodyBuilder.loadFromBinary(bytes_)  # kind:CUSTOM1
         bytes_ = bytes_[secretProofTransactionBody.getSize():]
-        return EmbeddedSecretProofTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, secretProofTransactionBody.secret, secretProofTransactionBody.hashAlgorithm, secretProofTransactionBody.recipientAddress, secretProofTransactionBody.proof)
+        return EmbeddedSecretProofTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, secretProofTransactionBody.recipientAddress, secretProofTransactionBody.secret, secretProofTransactionBody.hashAlgorithm, secretProofTransactionBody.proof)
+
+    def getRecipientAddress(self) -> UnresolvedAddressDto:
+        """Gets locked mosaic recipient address.
+        Returns:
+            Locked mosaic recipient address.
+        """
+        return self.secretProofTransactionBody.getRecipientAddress()
 
     def getSecret(self) -> Hash256Dto:
         """Gets secret.
@@ -85,13 +92,6 @@ class EmbeddedSecretProofTransactionBuilder(EmbeddedTransactionBuilder):
         """
         return self.secretProofTransactionBody.getHashAlgorithm()
 
-    def getRecipientAddress(self) -> UnresolvedAddressDto:
-        """Gets locked mosaic recipient address.
-        Returns:
-            Locked mosaic recipient address.
-        """
-        return self.secretProofTransactionBody.getRecipientAddress()
-
     def getProof(self) -> bytes:
         """Gets proof data.
         Returns:
