@@ -23,7 +23,7 @@
 
 from __future__ import annotations
 from .GeneratorUtils import GeneratorUtils
-from .KeyDto import KeyDto
+from .UnresolvedAddressDto import UnresolvedAddressDto
 from .UnresolvedMosaicIdDto import UnresolvedMosaicIdDto
 
 
@@ -31,23 +31,23 @@ class MosaicMetadataTransactionBodyBuilder:
     """Binary layout for a mosaic metadata transaction.
 
     Attributes:
-        targetPublicKey: Metadata target public key.
+        targetAddress: Metadata target address.
         scopedMetadataKey: Metadata key scoped to source, target and type.
         targetMosaicId: Target mosaic identifier.
         valueSizeDelta: Change in value size in bytes.
         value: Difference between existing value and new value \note when there is no existing value, new value is same this value \note when there is an existing value, new value is calculated as xor(previous-value, value).
     """
 
-    def __init__(self, targetPublicKey: KeyDto, scopedMetadataKey: int, targetMosaicId: UnresolvedMosaicIdDto, valueSizeDelta: int, value: bytes):
+    def __init__(self, targetAddress: UnresolvedAddressDto, scopedMetadataKey: int, targetMosaicId: UnresolvedMosaicIdDto, valueSizeDelta: int, value: bytes):
         """Constructor.
         Args:
-            targetPublicKey: Metadata target public key.
+            targetAddress: Metadata target address.
             scopedMetadataKey: Metadata key scoped to source, target and type.
             targetMosaicId: Target mosaic identifier.
             valueSizeDelta: Change in value size in bytes.
             value: Difference between existing value and new value \note when there is no existing value, new value is same this value \note when there is an existing value, new value is calculated as xor(previous-value, value).
         """
-        self.targetPublicKey = targetPublicKey
+        self.targetAddress = targetAddress
         self.scopedMetadataKey = scopedMetadataKey
         self.targetMosaicId = targetMosaicId
         self.valueSizeDelta = valueSizeDelta
@@ -62,8 +62,8 @@ class MosaicMetadataTransactionBodyBuilder:
             Instance of MosaicMetadataTransactionBodyBuilder.
         """
         bytes_ = bytes(payload)
-        targetPublicKey = KeyDto.loadFromBinary(bytes_)  # kind:CUSTOM1
-        bytes_ = bytes_[targetPublicKey.getSize():]
+        targetAddress = UnresolvedAddressDto.loadFromBinary(bytes_)  # kind:CUSTOM1
+        bytes_ = bytes_[targetAddress.getSize():]
         scopedMetadataKey = GeneratorUtils.bufferToUint(GeneratorUtils.getBytes(bytes_, 8))  # kind:SIMPLE
         bytes_ = bytes_[8:]
         targetMosaicId = UnresolvedMosaicIdDto.loadFromBinary(bytes_)  # kind:CUSTOM1
@@ -74,14 +74,14 @@ class MosaicMetadataTransactionBodyBuilder:
         bytes_ = bytes_[2:]
         value = GeneratorUtils.getBytes(bytes_, valueSize)  # kind:BUFFER
         bytes_ = bytes_[valueSize:]
-        return MosaicMetadataTransactionBodyBuilder(targetPublicKey, scopedMetadataKey, targetMosaicId, valueSizeDelta, value)
+        return MosaicMetadataTransactionBodyBuilder(targetAddress, scopedMetadataKey, targetMosaicId, valueSizeDelta, value)
 
-    def getTargetPublicKey(self) -> KeyDto:
-        """Gets metadata target public key.
+    def getTargetAddress(self) -> UnresolvedAddressDto:
+        """Gets metadata target address.
         Returns:
-            Metadata target public key.
+            Metadata target address.
         """
-        return self.targetPublicKey
+        return self.targetAddress
 
     def getScopedMetadataKey(self) -> int:
         """Gets metadata key scoped to source, target and type.
@@ -117,7 +117,7 @@ class MosaicMetadataTransactionBodyBuilder:
             Size in bytes.
         """
         size = 0
-        size += self.targetPublicKey.getSize()
+        size += self.targetAddress.getSize()
         size += 8  # scopedMetadataKey
         size += self.targetMosaicId.getSize()
         size += 2  # valueSizeDelta
@@ -131,7 +131,7 @@ class MosaicMetadataTransactionBodyBuilder:
             Serialized bytes.
         """
         bytes_ = bytes()
-        bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.targetPublicKey.serialize())  # kind:CUSTOM
+        bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.targetAddress.serialize())  # kind:CUSTOM
         bytes_ = GeneratorUtils.concatTypedArrays(bytes_, GeneratorUtils.uintToBuffer(self.getScopedMetadataKey(), 8))  # kind:SIMPLE
         bytes_ = GeneratorUtils.concatTypedArrays(bytes_, self.targetMosaicId.serialize())  # kind:CUSTOM
         bytes_ = GeneratorUtils.concatTypedArrays(bytes_, GeneratorUtils.uintToBuffer(self.getValueSizeDelta(), 2))  # kind:SIMPLE
