@@ -32,14 +32,18 @@ class NetworkTypeDto(Enum):
     Attributes:
         PUBLIC: public network.
         PUBLIC_TEST: public test network.
-        MIJIN: private network.
-        MIJIN_TEST: private test network.
+        MIJIN: mijin network.
+        MIJIN_TEST: mijin test network.
+        PRIVATE: private network.
+        PRIVATE_TEST: private test network.
     """
 
     PUBLIC = 104
     PUBLIC_TEST = 152
     MIJIN = 96
     MIJIN_TEST = 144
+    PRIVATE = 120
+    PRIVATE_TEST = 128
 
     @classmethod
     def loadFromBinary(cls, payload: bytes) -> NetworkTypeDto:
