@@ -25,7 +25,7 @@ from __future__ import annotations
 from .GeneratorUtils import GeneratorUtils
 from .AmountDto import AmountDto
 from .EntityTypeDto import EntityTypeDto
-from .FinalizationPointDto import FinalizationPointDto
+from .FinalizationEpochDto import FinalizationEpochDto
 from .KeyDto import KeyDto
 from .LinkActionDto import LinkActionDto
 from .NetworkTypeDto import NetworkTypeDto
@@ -43,7 +43,7 @@ class VotingKeyLinkTransactionBuilder(TransactionBuilder):
         votingKeyLinkTransactionBody: Voting key link transaction body.
     """
 
-    def __init__(self, size: int, signature: SignatureDto, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, fee: AmountDto, deadline: TimestampDto, linkedPublicKey: VotingKeyDto, startPoint: FinalizationPointDto, endPoint: FinalizationPointDto, linkAction: LinkActionDto):
+    def __init__(self, size: int, signature: SignatureDto, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, fee: AmountDto, deadline: TimestampDto, linkedPublicKey: VotingKeyDto, startEpoch: FinalizationEpochDto, endEpoch: FinalizationEpochDto, linkAction: LinkActionDto):
         """Constructor.
         Args:
             size: Entity size.
@@ -55,12 +55,12 @@ class VotingKeyLinkTransactionBuilder(TransactionBuilder):
             fee: Transaction fee.
             deadline: Transaction deadline.
             linkedPublicKey: Linked public key.
-            startPoint: Start finalization point.
-            endPoint: End finalization point.
+            startEpoch: Start finalization epoch.
+            endEpoch: End finalization epoch.
             linkAction: Link action.
         """
         super().__init__(size, signature, signerPublicKey, version, network, type, fee, deadline)
-        self.votingKeyLinkTransactionBody = VotingKeyLinkTransactionBodyBuilder(linkedPublicKey, startPoint, endPoint, linkAction)
+        self.votingKeyLinkTransactionBody = VotingKeyLinkTransactionBodyBuilder(linkedPublicKey, startEpoch, endEpoch, linkAction)
 
     @classmethod
     def loadFromBinary(cls, payload: bytes) -> VotingKeyLinkTransactionBuilder:
@@ -75,7 +75,7 @@ class VotingKeyLinkTransactionBuilder(TransactionBuilder):
         bytes_ = bytes_[superObject.getSize():]
         votingKeyLinkTransactionBody = VotingKeyLinkTransactionBodyBuilder.loadFromBinary(bytes_)  # kind:CUSTOM1
         bytes_ = bytes_[votingKeyLinkTransactionBody.getSize():]
-        return VotingKeyLinkTransactionBuilder(superObject.size, superObject.signature, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, superObject.fee, superObject.deadline, votingKeyLinkTransactionBody.linkedPublicKey, votingKeyLinkTransactionBody.startPoint, votingKeyLinkTransactionBody.endPoint, votingKeyLinkTransactionBody.linkAction)
+        return VotingKeyLinkTransactionBuilder(superObject.size, superObject.signature, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, superObject.fee, superObject.deadline, votingKeyLinkTransactionBody.linkedPublicKey, votingKeyLinkTransactionBody.startEpoch, votingKeyLinkTransactionBody.endEpoch, votingKeyLinkTransactionBody.linkAction)
 
     def getLinkedPublicKey(self) -> VotingKeyDto:
         """Gets linked public key.
@@ -84,19 +84,19 @@ class VotingKeyLinkTransactionBuilder(TransactionBuilder):
         """
         return self.votingKeyLinkTransactionBody.getLinkedPublicKey()
 
-    def getStartPoint(self) -> FinalizationPointDto:
-        """Gets start finalization point.
+    def getStartEpoch(self) -> FinalizationEpochDto:
+        """Gets start finalization epoch.
         Returns:
-            Start finalization point.
+            Start finalization epoch.
         """
-        return self.votingKeyLinkTransactionBody.getStartPoint()
+        return self.votingKeyLinkTransactionBody.getStartEpoch()
 
-    def getEndPoint(self) -> FinalizationPointDto:
-        """Gets end finalization point.
+    def getEndEpoch(self) -> FinalizationEpochDto:
+        """Gets end finalization epoch.
         Returns:
-            End finalization point.
+            End finalization epoch.
         """
-        return self.votingKeyLinkTransactionBody.getEndPoint()
+        return self.votingKeyLinkTransactionBody.getEndEpoch()
 
     def getLinkAction(self) -> LinkActionDto:
         """Gets link action.
